Module beamlit.models.request_total_by_origin_metric
====================================================

Classes
-------

`RequestTotalByOriginMetric(request_total_by_origin: beamlit.types.Unset | ForwardRef('RequestTotalByOriginMetricRequestTotalByOrigin') = <beamlit.types.Unset object>, request_total_by_origin_and_code: beamlit.types.Unset | ForwardRef('RequestTotalByOriginMetricRequestTotalByOriginAndCode') = <beamlit.types.Unset object>)`
:   Request total by origin metric
    
    Attributes:
        request_total_by_origin (Union[Unset, RequestTotalByOriginMetricRequestTotalByOrigin]): Request total by origin
        request_total_by_origin_and_code (Union[Unset, RequestTotalByOriginMetricRequestTotalByOriginAndCode]): Request
            total by origin and code
    
    Method generated by attrs for class RequestTotalByOriginMetric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `request_total_by_origin`
    :

    `request_total_by_origin_and_code`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :